ContextGenerateReactiveMask

Function ContextGenerateReactiveMask 

pub unsafe extern "C" fn ContextGenerateReactiveMask(
    context: *mut Context,
    params: *const GenerateReactiveDescription,
) -> ErrorCode
A helper function generate a Reactive mask from an opaque only texure and one containing translucent objects.

@param [in] context A pointer to a FfxFsr2Context structure. @param [in] params A pointer to a FfxFsr2GenerateReactiveDescription structure

@retval FFX_OK The operation completed successfully.

@ingroup FSR2