pub unsafe extern "C" fn ResourceIsNull(resource: Resource) -> boolExpand description
A helper function to check if a resource is
@param [in] resource A
@returns
true The
@ingroup FSR2
pub unsafe extern "C" fn ResourceIsNull(resource: Resource) -> boolA helper function to check if a resource is
@param [in] resource A
@returns
true The
@ingroup FSR2