PipelineDescription

Struct PipelineDescription 

#[repr(C)]
pub struct PipelineDescription { pub contextFlags: u32, pub samplers: *mut FilterType, pub samplerCount: usize, pub rootConstantBufferSizes: *const u32, pub rootConstantBufferCount: u32, }
A structure containing the description used to create a FfxPipeline structure.

A pipeline is the name given to a shader and the collection of state that is required to dispatch it. In the context of FSR2 and its architecture this means that a FfxPipelineDescription will map to either a monolithic object in an explicit API (such as a PipelineStateObject in DirectX 12). Or a shader and some ancillary API objects (in something like DirectX 11).

The contextFlags field contains a copy of the flags passed to ffxFsr2ContextCreate via the flags field of the FfxFsr2InitializationParams structure. These flags are used to determine which permutation of a pipeline for a specific FfxFsr2Pass should be used to implement the features required by each application, as well as to acheive the best performance on specific target hardware configurations.

When using one of the provided backends for FSR2 (such as DirectX 12 or Vulkan) the data required to create a pipeline is compiled offline and included into the backend library that you are using. For cases where the backend interface is overriden by providing custom callback function implementations care should be taken to respect the contents of the contextFlags field in order to correctly support the options provided by FSR2, and acheive best performance.

@ingroup FSR2

Fields

contextFlags: u32

< A collection of FfxFsr2InitializationFlagBits which were passed to the context.

samplers: *mut FilterType

< Array of static samplers.

samplerCount: usize

< The number of samples contained inside samplers.

rootConstantBufferSizes: *const u32

< Array containing the sizes of the root constant buffers (count of 32 bit elements).

rootConstantBufferCount: u32

< The number of root constants contained within rootConstantBufferSizes.