RegisterResourceFunc

Type Alias RegisterResourceFunc 

pub type RegisterResourceFunc = Option<unsafe extern "C" fn(backendInterface: *mut Interface, inResource: *const Resource, outResource: *mut ResourceInternal) -> ErrorCode>;
Register a resource in the backend for the current frame.

Since FSR2 and the backend are not aware how many different resources will get passed to FSR2 over time, it’s not safe to register all resources simultaneously in the backend. Also passed resources may not be valid after the dispatch call. As a result it’s safest to register them as FfxResourceInternal and clear them at the end of the dispatch call.

@param [in] backendInterface A pointer to the backend interface. @param [in] inResource A pointer to a FfxResource. @param [out] outResource A pointer to a FfxResourceInternal object.

@retval FFX_OK The operation completed successfully. @retval Anything else The operation failed.

@ingroup FSR2

Aliased Type

pub enum RegisterResourceFunc {
    None,
    Some(unsafe extern "C" fn(*mut Interface, *const Resource, *mut ResourceInternal) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut Interface, *const Resource, *mut ResourceInternal) -> i32)

Some value of type T.