pub unsafe extern "C" fn ContextGenerateReactiveMask(
context: *mut Context,
params: *const GenerateReactiveDescription,
) -> ErrorCodeExpand description
A helper function generate a Reactive mask from an opaque only texure and one containing translucent objects.
@param [in] context A pointer to a
@retval FFX_OK The operation completed successfully.
@ingroup FSR2