#[repr(C)]pub struct PipelineDescription {
pub contextFlags: u32,
pub samplers: *mut FilterType,
pub samplerCount: usize,
pub rootConstantBufferSizes: *const u32,
pub rootConstantBufferCount: u32,
}Expand description
A structure containing the description used to create a
A pipeline is the name given to a shader and the collection of state that
is required to dispatch it. In the context of FSR2 and its architecture
this means that a
The
When using one of the provided backends for FSR2 (such as DirectX 12 or
Vulkan) the data required to create a pipeline is compiled offline and
included into the backend library that you are using. For cases where the
backend interface is overriden by providing custom callback function
implementations care should be taken to respect the contents of the
@ingroup FSR2
Fields
contextFlags: u32< A collection of
samplers: *mut FilterType< Array of static samplers.
samplerCount: usize< The number of samples contained inside
rootConstantBufferSizes: *const u32< Array containing the sizes of the root constant buffers (count of 32 bit elements).
rootConstantBufferCount: u32< The number of root constants contained within